0.2.2
-----
* build wheels

0.2.1
-----
* small updates to docs, move to RST for PyPI compliance

0.2.0
----------
* drop support for Django 1.4, 1.5 and 1.6
* add support for Django 1.7, 1.8, 1.9
* add Python 3 support
* update tox and Travis CI configs
* updated description on pypi (thanks to lowks)

0.1.1
-----------------------------------------
* initial release
